@@ -476,7 +476,7 @@ public class CodeEmitter extends LocalVariablesSorter {
     }
 
     public void super_invoke(Signature sig) {
-        emit_invoke(Constants.INVOKESPECIAL, ce.getSuperType(), sig);
+        emit_invoke(Constants.INVOKESPECIAL, ce.getSuperType(), sig, false);
     }
 
     public void invoke_constructor(Type type) {
@@ -491,7 +491,7 @@ public class CodeEmitter extends LocalVariablesSorter {
         invoke_constructor(ce.getClassType());
     }
 
-    private void emit_invoke(int opcode, Type type, Signature sig) {
+    private void emit_invoke(int opcode, Type type, Signature sig, boolean isInterface) {
         if (sig.getName().equals(Constants.CONSTRUCTOR_NAME) &&
             ((opcode == Constants.INVOKEVIRTUAL) ||
              (opcode == Constants.INVOKESTATIC))) {
@@ -501,19 +501,24 @@ public class CodeEmitter extends LocalVariablesSorter {
                            type.getInternalName(),
                            sig.getName(),
                            sig.getDescriptor(),
-                           opcode == Opcodes.INVOKEINTERFACE);
+                           isInterface);
     }
     
     public void invoke_interface(Type owner, Signature sig) {
-        emit_invoke(Constants.INVOKEINTERFACE, owner, sig);
+        emit_invoke(Constants.INVOKEINTERFACE, owner, sig, true);
     }
 
     public void invoke_virtual(Type owner, Signature sig) {
-        emit_invoke(Constants.INVOKEVIRTUAL, owner, sig);
+        emit_invoke(Constants.INVOKEVIRTUAL, owner, sig, false);
     }
 
+    @Deprecated
     public void invoke_static(Type owner, Signature sig) {
-        emit_invoke(Constants.INVOKESTATIC, owner, sig);
+        invoke_static(owner, sig, false);
+    }
+
+    public void invoke_static(Type owner, Signature sig, boolean isInterface) {
+        emit_invoke(Constants.INVOKESTATIC, owner, sig, isInterface);
     }
 
     public void invoke_virtual_this(Signature sig) {
@@ -525,7 +530,7 @@ public class CodeEmitter extends LocalVariablesSorter {
     }
 
     public void invoke_constructor(Type type, Signature sig) {
-        emit_invoke(Constants.INVOKESPECIAL, type, sig);
+        emit_invoke(Constants.INVOKESPECIAL, type, sig, false);
     }
 
     public void invoke_constructor_this(Signature sig) {
@@ -850,7 +855,7 @@ public class CodeEmitter extends LocalVariablesSorter {
         if (sig.getName().equals(Constants.CONSTRUCTOR_NAME)) {
             invoke_constructor(type, sig);
         } else if (TypeUtils.isStatic(method.getModifiers())) {
-            invoke_static(type, sig);
+            invoke_static(type, sig, TypeUtils.isInterface(classInfo.getModifiers()));
         } else if (TypeUtils.isInterface(classInfo.getModifiers())) {
             invoke_interface(type, sig);
         } else {
