@@ -31,6 +31,6 @@ interface CallbackGenerator
         int getIndex(MethodInfo method);
         void emitCallback(CodeEmitter ce, int index);
         Signature getImplSignature(MethodInfo method);
-        void emitInvoke(CodeEmitter e, MethodInfo method);
+        void emitLoadArgsAndInvoke(CodeEmitter e, MethodInfo method);
     }
 }
